Module api

Module api 

Helper functions for managing the Agent Chain API.

This module is only relevant for Agent Chain developers, not for users.

Warning: This module and its submodules are for internal use only. Do not use them in your own code. We may change the API at any time with no warning.

Structs

AgentChainBetaWarning
A warning type for beta features in Agent Chain.
AgentChainDeprecationWarning
A warning type for deprecated features in Agent Chain.
AgentChainPendingDeprecationWarning
A warning type for pending deprecations in Agent Chain.
BetaParams
Parameters for configuring beta warnings.
DeprecationParams
Parameters for configuring deprecation warnings.
RenameParameterParams
Parameters for renaming a deprecated parameter.
SuppressBetaWarnings
Guard that suppresses beta warnings while it exists.
SuppressDeprecationWarnings
Guard that suppresses deprecation warnings while it exists.

Functions

as_import_path
Convert a file path to an import path (module path format).
get_relative_path
Get the path of the file as a relative path to a base directory.
handle_renamed_parameter
Check if an old parameter name was used and emit a deprecation warning.
is_caller_internal
Checks if the caller module is internal to agent-chain.
suppress_beta_warnings
Suppress beta warnings within a scope.
suppress_deprecation_warnings
Suppress deprecation warnings within a scope.
surface_beta_warnings
Enable beta warnings (unmute them).
surface_deprecation_warnings
Enable deprecation warnings (unmute them).
warn_beta
Display a standardized beta warning.
warn_deprecated
Display a standardized deprecation warning.