InMemoryCache

Struct InMemoryCache 

pub struct InMemoryCache { /* private fields */ }
Cache that stores things in memory.

Implementations

Source

impl InMemoryCache

pub fn new(maxsize: Option<usize>) -> Self

Initialize with empty cache.

Arguments
  • maxsize - The maximum number of items to store in the cache. If None, the cache has no maximum size. If the cache exceeds the maximum size, the oldest items are removed.
Panics

Panics if maxsize is less than or equal to 0.

pub fn unbounded() -> Self

Create a new InMemoryCache with no maximum size.