BaseCallbackHandler

Trait BaseCallbackHandler 

pub trait BaseCallbackHandler:
    LLMManagerMixin
    + ChainManagerMixin
    + ToolManagerMixin
    + RetrieverManagerMixin
    + CallbackManagerMixin
    + RunManagerMixin
    + Send
    + Sync
    + Debug {
    // Provided methods
    fn raise_error(&self) -> bool { ... }
    fn run_inline(&self) -> bool { ... }
    fn ignore_llm(&self) -> bool { ... }
    fn ignore_retry(&self) -> bool { ... }
    fn ignore_chain(&self) -> bool { ... }
    fn ignore_agent(&self) -> bool { ... }
    fn ignore_retriever(&self) -> bool { ... }
    fn ignore_chat_model(&self) -> bool { ... }
    fn ignore_custom_event(&self) -> bool { ... }
    fn name(&self) -> &str { ... }
}
Base callback handler for LangChain.

This trait combines all the mixin traits and provides the base interface for callback handlers. Handlers can override specific methods they care about.

Provided Methods

fn raise_error(&self) -> bool

Whether to raise an error if an exception occurs.

fn run_inline(&self) -> bool

Whether to run the callback inline.

fn ignore_llm(&self) -> bool

Whether to ignore LLM callbacks.

fn ignore_retry(&self) -> bool

Whether to ignore retry callbacks.

fn ignore_chain(&self) -> bool

Whether to ignore chain callbacks.

fn ignore_agent(&self) -> bool

Whether to ignore agent callbacks.

fn ignore_retriever(&self) -> bool

Whether to ignore retriever callbacks.

fn ignore_chat_model(&self) -> bool

Whether to ignore chat model callbacks.

fn ignore_custom_event(&self) -> bool

Whether to ignore custom events.

fn name(&self) -> &str

Get a unique name for this handler. Note: This is a Rust-specific addition for debugging purposes.

Implementors