BoundChatModel

Struct BoundChatModel 

pub struct BoundChatModel<M: ChatModel> { /* private fields */ }
A chat model that has been bound with tools (generic version).

This wraps an underlying chat model and includes tool definitions that will be passed to the model on each invocation.

Implementations

Source

impl<M: ChatModel> BoundChatModel<M>

pub fn new(model: M, tools: Vec<Arc<dyn Tool + Send + Sync>>) -> Self

Create a new bound chat model.

pub fn with_tool_choice(self, tool_choice: ToolChoice) -> Self

Set the tool choice.

pub fn tool_definitions(&self) -> Vec<ToolDefinition>

Get the tool definitions.

pub fn model(&self) -> &M

Get a reference to the underlying model.

pub fn tools(&self) -> &[Arc<dyn Tool + Send + Sync>]

Get the tools.

pub fn tool_choice(&self) -> Option<&ToolChoice>

Get the tool choice.

pub async fn invoke(&self, messages: Vec<BaseMessage>) -> BaseMessage

Invoke the model with messages.

This generates a response using the bound tools.