ChatSession

Struct ChatSession 

pub struct ChatSession {
    pub messages: Option<Vec<BaseMessage>>,
    pub functions: Option<Vec<Value>>,
}
Chat Session.

A Chat Session represents a single conversation, channel, or other group of messages.

Example

use agent_chain_core::chat_sessions::ChatSession;
use agent_chain_core::messages::{BaseMessage, HumanMessage, AIMessage};

let session = ChatSession {
    messages: Some(vec![
        BaseMessage::Human(HumanMessage::new("Hello!")),
        BaseMessage::AI(AIMessage::new("Hi there!")),
    ]),
    functions: None,
};

Fields

messages: Option<Vec<BaseMessage>>

A sequence of the LangChain chat messages loaded from the source.

functions: Option<Vec<Value>>

A sequence of the function calling specs for the messages.

Implementations

Source

impl ChatSession

pub fn new() -> Self

Create a new empty chat session.

pub fn with_messages(messages: Vec<BaseMessage>) -> Self

Create a chat session with the given messages.

pub fn with_messages_and_functions( messages: Vec<BaseMessage>, functions: Vec<Value>, ) -> Self

Create a chat session with the given messages and functions.

pub fn messages(&self) -> &[BaseMessage]

Get the messages in this session, or an empty slice if none.

pub fn functions(&self) -> &[Value]

Get the functions in this session, or an empty slice if none.

pub fn has_messages(&self) -> bool

Check if this session has any messages.

pub fn has_functions(&self) -> bool

Check if this session has any functions.