Blob

Struct Blob 

pub struct Blob {
    pub id: Option<String>,
    pub metadata: HashMap<String, Value>,
    pub data: Option<BlobData>,
    pub mimetype: Option<String>,
    pub encoding: String,
    pub path: Option<PathBuf>,
}
Raw data abstraction for document loading and file processing.

Represents raw bytes or text, either in-memory or by file reference. Used primarily by document loaders to decouple data loading from parsing.

Inspired by Mozilla’s Blob

Examples

Initialize a blob from in-memory data:

use agent_chain_core::documents::Blob;

let blob = Blob::from_data("Hello, world!");

// Read the blob as a string
assert_eq!(blob.as_string().unwrap(), "Hello, world!");

// Read the blob as bytes
assert_eq!(blob.as_bytes().unwrap(), b"Hello, world!");

Load from memory and specify MIME type and metadata:

use agent_chain_core::documents::Blob;
use std::collections::HashMap;

let blob = Blob::builder()
    .data("Hello, world!")
    .mime_type("text/plain")
    .metadata(HashMap::from([("source".to_string(), serde_json::json!("https://example.com"))]))
    .build()
    .unwrap();

Fields

id: Option<String>

An optional identifier for the blob.

metadata: HashMap<String, Value>

Arbitrary metadata associated with the blob.

data: Option<BlobData>

Raw data associated with the blob (bytes or string).

mimetype: Option<String>

MIME type, not to be confused with a file extension.

encoding: String

Encoding to use if decoding the bytes into a string. Uses utf-8 as default encoding if decoding to string.

path: Option<PathBuf>

Location where the original content was found.

Implementations

Source

impl Blob

pub fn builder() -> BlobBuilder

Create a new Blob builder.

pub fn from_data(data: impl Into<String>) -> Self

Create a Blob from in-memory data (string).

pub fn from_bytes(data: Vec<u8>) -> Self

Create a Blob from in-memory bytes.

pub fn from_path( path: impl AsRef<Path>, mime_type: Option<String>, encoding: Option<String>, metadata: Option<HashMap<String, Value>>, ) -> Self

Load the blob from a path.

The data is not loaded immediately - the blob treats the path as a reference to the underlying data.

Arguments
  • path - Path to the file
  • mime_type - Optional MIME type (will be guessed from extension if not provided)
  • encoding - Encoding to use (defaults to “utf-8”)
  • metadata - Optional metadata
pub fn source(&self) -> Option<String>

The source location of the blob as string if known otherwise none.

If a path is associated with the Blob, it will default to the path location. Unless explicitly set via a metadata field called 'source', in which case that value will be used instead.

pub fn as_string(&self) -> Result<String>

Read data as a string.

Errors

Returns an error if the blob cannot be represented as a string.

pub fn as_bytes(&self) -> Result<Vec<u8>>

Read data as bytes.

Errors

Returns an error if the blob cannot be represented as bytes.

pub fn as_bytes_io(&self) -> Result<Box<dyn Read>>

Read data as a byte stream (returns a reader).

Errors

Returns an error if the blob cannot be represented as a byte stream.