pub struct FakeListLLM { /* private fields */ }Expand description
Fake LLM for testing purposes.
Returns responses from a list in order, cycling back to the start when the end is reached.
Implementations
Sourceimpl FakeListLLM
impl FakeListLLM
Sourcepub fn with_sleep(self, duration: Duration) -> Self
pub fn with_sleep(self, duration: Duration) -> Self
Set the sleep duration between responses.
Sourcepub fn with_config(self, config: LLMConfig) -> Self
pub fn with_config(self, config: LLMConfig) -> Self
Set the configuration.
Sourcepub fn current_index(&self) -> usize
pub fn current_index(&self) -> usize
Get the current index.