pub struct FakeStreamingListLLM { /* private fields */ }Expand description
Fake streaming list LLM for testing purposes.
An LLM that will return responses from a list in order, with support for streaming character by character.
Implementations
Sourceimpl FakeStreamingListLLM
impl FakeStreamingListLLM
Sourcepub fn new(responses: Vec<String>) -> Self
pub fn new(responses: Vec<String>) -> Self
Create a new FakeStreamingListLLM with the given responses.
Sourcepub fn with_sleep(self, duration: Duration) -> Self
pub fn with_sleep(self, duration: Duration) -> Self
Set the sleep duration between chunks.
Sourcepub fn with_config(self, config: LLMConfig) -> Self
pub fn with_config(self, config: LLMConfig) -> Self
Set the configuration.
Sourcepub fn with_error_on_chunk(self, chunk_number: usize) -> Self
pub fn with_error_on_chunk(self, chunk_number: usize) -> Self
Set the chunk number to error on.
Sourcepub fn current_index(&self) -> usize
pub fn current_index(&self) -> usize
Get the current index.