GenericFakeChatModel

Struct GenericFakeChatModel 

pub struct GenericFakeChatModel { /* private fields */ }
Generic fake chat model that can be used to test the chat model interface.

  • Chat model should be usable in both sync and async tests
  • Invokes on_llm_new_token to allow for testing of callback related code for new tokens.
  • Includes logic to break messages into message chunks to facilitate testing of streaming.

Implementations

Source

impl GenericFakeChatModel

pub fn new<I>(messages: I) -> Self
where I: Iterator<Item = AIMessage> + Send + 'static,

Create a new GenericFakeChatModel with an iterator of messages.

pub fn from_vec(messages: Vec<AIMessage>) -> Self

Create from a vector of messages.

pub fn from_strings(messages: Vec<String>) -> Self

Create from a vector of strings (converted to AIMessages).

pub fn with_config(self, config: ChatModelConfig) -> Self

Set the configuration.