pub struct ModelProfile {Show 16 fields
pub max_input_tokens: Option<u32>,
pub image_inputs: Option<bool>,
pub image_url_inputs: Option<bool>,
pub pdf_inputs: Option<bool>,
pub audio_inputs: Option<bool>,
pub video_inputs: Option<bool>,
pub image_tool_message: Option<bool>,
pub pdf_tool_message: Option<bool>,
pub max_output_tokens: Option<u32>,
pub reasoning_output: Option<bool>,
pub image_outputs: Option<bool>,
pub audio_outputs: Option<bool>,
pub video_outputs: Option<bool>,
pub tool_calling: Option<bool>,
pub tool_choice: Option<bool>,
pub structured_output: Option<bool>,
}Expand description
Model profile providing information about chat model capabilities.
This is a beta feature and the format may be subject to change.
Provides information about:
- Input constraints (context window, supported modalities)
- Output constraints (max output tokens, supported outputs)
- Tool calling capabilities
- Structured output support
Fields
max_input_tokens: Option<u32>Maximum context window (tokens).
image_inputs: Option<bool>Whether image inputs are supported.
image_url_inputs: Option<bool>Whether image URL inputs are supported.
pdf_inputs: Option<bool>Whether PDF inputs are supported.
audio_inputs: Option<bool>Whether audio inputs are supported.
video_inputs: Option<bool>Whether video inputs are supported.
image_tool_message: Option<bool>Whether images can be included in tool messages.
pdf_tool_message: Option<bool>Whether PDFs can be included in tool messages.
max_output_tokens: Option<u32>Maximum output tokens.
reasoning_output: Option<bool>Whether the model supports reasoning / chain-of-thought.
image_outputs: Option<bool>Whether image outputs are supported.
audio_outputs: Option<bool>Whether audio outputs are supported.
video_outputs: Option<bool>Whether video outputs are supported.
tool_calling: Option<bool>Whether the model supports tool calling.
tool_choice: Option<bool>Whether the model supports tool choice.
structured_output: Option<bool>Whether the model supports a native structured output feature.
Implementations
Sourceimpl ModelProfile
impl ModelProfile
Sourcepub fn with_max_input_tokens(self, tokens: u32) -> Self
pub fn with_max_input_tokens(self, tokens: u32) -> Self
Set the maximum input tokens.
Sourcepub fn with_max_output_tokens(self, tokens: u32) -> Self
pub fn with_max_output_tokens(self, tokens: u32) -> Self
Set the maximum output tokens.
Sourcepub fn with_image_inputs(self, supported: bool) -> Self
pub fn with_image_inputs(self, supported: bool) -> Self
Set whether image inputs are supported.
Sourcepub fn with_image_url_inputs(self, supported: bool) -> Self
pub fn with_image_url_inputs(self, supported: bool) -> Self
Set whether image URL inputs are supported.
Sourcepub fn with_pdf_inputs(self, supported: bool) -> Self
pub fn with_pdf_inputs(self, supported: bool) -> Self
Set whether PDF inputs are supported.
Sourcepub fn with_audio_inputs(self, supported: bool) -> Self
pub fn with_audio_inputs(self, supported: bool) -> Self
Set whether audio inputs are supported.
Sourcepub fn with_video_inputs(self, supported: bool) -> Self
pub fn with_video_inputs(self, supported: bool) -> Self
Set whether video inputs are supported.
Sourcepub fn with_image_tool_message(self, supported: bool) -> Self
pub fn with_image_tool_message(self, supported: bool) -> Self
Set whether images can be included in tool messages.
Sourcepub fn with_pdf_tool_message(self, supported: bool) -> Self
pub fn with_pdf_tool_message(self, supported: bool) -> Self
Set whether PDFs can be included in tool messages.
Sourcepub fn with_reasoning_output(self, supported: bool) -> Self
pub fn with_reasoning_output(self, supported: bool) -> Self
Set whether reasoning output is supported.
Sourcepub fn with_image_outputs(self, supported: bool) -> Self
pub fn with_image_outputs(self, supported: bool) -> Self
Set whether image outputs are supported.
Sourcepub fn with_audio_outputs(self, supported: bool) -> Self
pub fn with_audio_outputs(self, supported: bool) -> Self
Set whether audio outputs are supported.
Sourcepub fn with_video_outputs(self, supported: bool) -> Self
pub fn with_video_outputs(self, supported: bool) -> Self
Set whether video outputs are supported.
Sourcepub fn with_tool_calling(self, supported: bool) -> Self
pub fn with_tool_calling(self, supported: bool) -> Self
Set whether tool calling is supported.
Sourcepub fn with_tool_choice(self, supported: bool) -> Self
pub fn with_tool_choice(self, supported: bool) -> Self
Set whether tool choice is supported.
Sourcepub fn with_structured_output(self, supported: bool) -> Self
pub fn with_structured_output(self, supported: bool) -> Self
Set whether structured output is supported.
Sourcepub fn supports_multimodal_inputs(&self) -> bool
pub fn supports_multimodal_inputs(&self) -> bool
Check if the model supports multimodal inputs.
Sourcepub fn supports_multimodal_outputs(&self) -> bool
pub fn supports_multimodal_outputs(&self) -> bool
Check if the model supports multimodal outputs.
Sourcepub fn supports_tool_calling(&self) -> bool
pub fn supports_tool_calling(&self) -> bool
Check if the model supports tool calling.
Sourcepub fn supports_structured_output(&self) -> bool
pub fn supports_structured_output(&self) -> bool
Check if the model supports structured output.