pub struct ParrotFakeChatModel { /* private fields */ }Expand description
Generic fake chat model that echoes the last message.
- Chat model should be usable in both sync and async tests
Implementations
Sourceimpl ParrotFakeChatModel
impl ParrotFakeChatModel
Sourcepub fn with_config(self, config: ChatModelConfig) -> Self
pub fn with_config(self, config: ChatModelConfig) -> Self
Set the configuration.