SimpleChatModel

Trait SimpleChatModel 

pub trait SimpleChatModel: BaseChatModel {
    // Required method
    fn _call<'life0, 'life1, 'async_trait>(
        &'life0 self,
        messages: Vec<BaseMessage>,
        stop: Option<Vec<String>>,
        run_manager: Option<&'life1 CallbackManagerForLLMRun>,
    ) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>
       where Self: 'async_trait,
             'life0: 'async_trait,
             'life1: 'async_trait;
}
Simplified implementation for a chat model to inherit from.

This implementation is primarily here for backwards compatibility. For new implementations, please use BaseChatModel directly.

Required Methods

fn _call<'life0, 'life1, 'async_trait>( &'life0 self, messages: Vec<BaseMessage>, stop: Option<Vec<String>>, run_manager: Option<&'life1 CallbackManagerForLLMRun>, ) -> Pin<Box<dyn Future<Output = Result<String>> + Send + 'async_trait>>
where Self: 'async_trait, 'life0: 'async_trait, 'life1: 'async_trait,

Simple call method that takes messages and returns a string.

Implementations should override this method.

Implementors