pub struct ChatMessage { /* private fields */ }Expand description
A chat message that can be assigned an arbitrary speaker (role).
Use this when you need to specify a custom role that isn’t covered by the standard message types (Human, AI, System, Tool).
This corresponds to ChatMessage in LangChain Python.
Implementations
Sourceimpl ChatMessage
impl ChatMessage
Sourcepub fn new(role: impl Into<String>, content: impl Into<String>) -> Self
pub fn new(role: impl Into<String>, content: impl Into<String>) -> Self
Create a new chat message with the given role.
Sourcepub fn with_id(
id: impl Into<String>,
role: impl Into<String>,
content: impl Into<String>,
) -> Self
pub fn with_id( id: impl Into<String>, role: impl Into<String>, content: impl Into<String>, ) -> Self
Create a new chat message with an explicit ID.
Use this when deserializing or reconstructing messages where the ID must be preserved.
Sourcepub fn additional_kwargs(&self) -> &HashMap<String, Value>
pub fn additional_kwargs(&self) -> &HashMap<String, Value>
Get additional kwargs.
Sourcepub fn response_metadata(&self) -> &HashMap<String, Value>
pub fn response_metadata(&self) -> &HashMap<String, Value>
Get response metadata.
Sourcepub fn with_response_metadata(
self,
response_metadata: HashMap<String, Value>,
) -> Self
pub fn with_response_metadata( self, response_metadata: HashMap<String, Value>, ) -> Self
Set response metadata.