pub struct FunctionMessage { /* private fields */ }Expand description
A function message in the conversation.
FunctionMessage objects are an older version of the ToolMessage schema, and
do not contain the tool_call_id field.
The tool_call_id field is used to associate the tool call request with the
tool call response. Useful in situations where a chat model is able
to request multiple tool calls in parallel.
This corresponds to FunctionMessage in LangChain Python.
Implementations
Sourceimpl FunctionMessage
impl FunctionMessage
Sourcepub fn new(name: impl Into<String>, content: impl Into<String>) -> Self
pub fn new(name: impl Into<String>, content: impl Into<String>) -> Self
Create a new function message.
Arguments
name- The name of the function that was executed.content- The result of the function execution.
Sourcepub fn with_id(
id: impl Into<String>,
name: impl Into<String>,
content: impl Into<String>,
) -> Self
pub fn with_id( id: impl Into<String>, name: impl Into<String>, content: impl Into<String>, ) -> Self
Create a new function message with an explicit ID.
Use this when deserializing or reconstructing messages where the ID must be preserved.
Sourcepub fn additional_kwargs(&self) -> &HashMap<String, Value>
pub fn additional_kwargs(&self) -> &HashMap<String, Value>
Get additional kwargs.
Sourcepub fn response_metadata(&self) -> &HashMap<String, Value>
pub fn response_metadata(&self) -> &HashMap<String, Value>
Get response metadata.
Sourcepub fn with_response_metadata(
self,
response_metadata: HashMap<String, Value>,
) -> Self
pub fn with_response_metadata( self, response_metadata: HashMap<String, Value>, ) -> Self
Set response metadata.