pub struct HumanMessageChunk { /* private fields */ }Expand description
Human message chunk (yielded when streaming).
This corresponds to HumanMessageChunk in LangChain Python.
Implementations
Sourceimpl HumanMessageChunk
impl HumanMessageChunk
Sourcepub fn new(content: impl Into<String>) -> Self
pub fn new(content: impl Into<String>) -> Self
Create a new human message chunk with text content.
Sourcepub fn with_id(id: impl Into<String>, content: impl Into<String>) -> Self
pub fn with_id(id: impl Into<String>, content: impl Into<String>) -> Self
Create a new human message chunk with an ID.
Sourcepub fn message_content(&self) -> &MessageContent
pub fn message_content(&self) -> &MessageContent
Get the full message content.
Sourcepub fn additional_kwargs(&self) -> &HashMap<String, Value>
pub fn additional_kwargs(&self) -> &HashMap<String, Value>
Get additional kwargs.
Sourcepub fn response_metadata(&self) -> &HashMap<String, Value>
pub fn response_metadata(&self) -> &HashMap<String, Value>
Get response metadata.
Sourcepub fn concat(&self, other: &HumanMessageChunk) -> HumanMessageChunk
pub fn concat(&self, other: &HumanMessageChunk) -> HumanMessageChunk
Concatenate this chunk with another chunk.
Sourcepub fn to_message(&self) -> HumanMessage
pub fn to_message(&self) -> HumanMessage
Convert this chunk to a complete HumanMessage.