pub struct InputTokenDetails {
pub audio: Option<i64>,
pub cache_creation: Option<i64>,
pub cache_read: Option<i64>,
}Expand description
Breakdown of input token counts.
Does not need to sum to full input token count. Does not need to have all keys.
Fields
audio: Option<i64>Audio input tokens.
cache_creation: Option<i64>Input tokens that were cached and there was a cache miss.
cache_read: Option<i64>Input tokens that were cached and there was a cache hit.