pub struct ToolCallChunkBlock {
pub block_type: String,
pub id: Option<String>,
pub name: Option<String>,
pub args: Option<String>,
pub index: Option<BlockIndex>,
pub extras: Option<HashMap<String, Value>>,
}Expand description
A chunk of a tool call (yielded when streaming, content block version).
Fields
block_type: StringType of the content block. Always “tool_call_chunk”.
id: Option<String>An identifier associated with the tool call.
name: Option<String>The name of the tool to be called.
args: Option<String>The arguments to the tool call (as a string, since it may be partial JSON).
index: Option<BlockIndex>The index of the tool call in a sequence.
extras: Option<HashMap<String, Value>>Provider-specific metadata.
Implementations