pub struct ToolMessage { /* private fields */ }Expand description
A tool message containing the result of a tool call.
ToolMessage objects contain the result of a tool invocation. Typically, the result
is encoded inside the content field.
This corresponds to ToolMessage in LangChain Python.
Implementations
Sourceimpl ToolMessage
impl ToolMessage
Sourcepub fn new(content: impl Into<String>, tool_call_id: impl Into<String>) -> Self
pub fn new(content: impl Into<String>, tool_call_id: impl Into<String>) -> Self
Create a new tool message.
Sourcepub fn with_id(
id: impl Into<String>,
content: impl Into<String>,
tool_call_id: impl Into<String>,
) -> Self
pub fn with_id( id: impl Into<String>, content: impl Into<String>, tool_call_id: impl Into<String>, ) -> Self
Create a new tool message with an explicit ID.
Use this when deserializing or reconstructing messages where the ID must be preserved.
Sourcepub fn error(
content: impl Into<String>,
tool_call_id: impl Into<String>,
) -> Self
pub fn error( content: impl Into<String>, tool_call_id: impl Into<String>, ) -> Self
Create a new tool message with error status.
Sourcepub fn with_artifact(
content: impl Into<String>,
tool_call_id: impl Into<String>,
artifact: Value,
) -> Self
pub fn with_artifact( content: impl Into<String>, tool_call_id: impl Into<String>, artifact: Value, ) -> Self
Create a new tool message with an artifact.
Sourcepub fn tool_call_id(&self) -> &str
pub fn tool_call_id(&self) -> &str
Get the tool call ID this message responds to.
Sourcepub fn status(&self) -> &ToolStatus
pub fn status(&self) -> &ToolStatus
Get the status of the tool invocation.
Sourcepub fn additional_kwargs(&self) -> &HashMap<String, Value>
pub fn additional_kwargs(&self) -> &HashMap<String, Value>
Get additional kwargs.
Sourcepub fn response_metadata(&self) -> &HashMap<String, Value>
pub fn response_metadata(&self) -> &HashMap<String, Value>
Get response metadata.