pub struct OutputParserError {
pub message: String,
pub llm_output: Option<String>,
pub send_to_llm: bool,
pub observation: Option<String>,
}Expand description
Error type for output parser operations.
Fields
message: StringThe error message.
llm_output: Option<String>The raw LLM output that caused the error.
send_to_llm: boolWhether the error is retryable.
observation: Option<String>Observation to send back to the LLM if retrying.
Implementations
Sourceimpl OutputParserError
impl OutputParserError
Sourcepub fn parse_error(
message: impl Into<String>,
llm_output: impl Into<String>,
) -> Self
pub fn parse_error( message: impl Into<String>, llm_output: impl Into<String>, ) -> Self
Create a parse error with the LLM output.
Sourcepub fn with_send_to_llm(self, send: bool) -> Self
pub fn with_send_to_llm(self, send: bool) -> Self
Set whether this error should be sent back to the LLM.
Sourcepub fn with_observation(self, observation: impl Into<String>) -> Self
pub fn with_observation(self, observation: impl Into<String>) -> Self
Set the observation to send back to the LLM.
Sourcepub fn with_llm_output(self, llm_output: impl Into<String>) -> Self
pub fn with_llm_output(self, llm_output: impl Into<String>) -> Self
Set the LLM output.