pub struct RunInfo {
pub run_id: Uuid,
}Expand description
Class that contains metadata for a single execution of a Chain or model.
Defined for backwards compatibility with older versions of langchain_core.
This model will likely be deprecated in the future.
Users can acquire the run_id information from callbacks or via run_id information present in the astream_event API (depending on the use case).
Fields
run_id: UuidA unique identifier for the model or chain run.
Implementations