InMemoryRateLimiter

Struct InMemoryRateLimiter 

pub struct InMemoryRateLimiter { /* private fields */ }
An in memory rate limiter based on a token bucket algorithm.

This is an in memory rate limiter, so it cannot rate limit across different processes.

The rate limiter only allows time-based rate limiting and does not take into account any information about the input or the output, so it cannot be used to rate limit based on the size of the request.

It is thread safe and can be used in either a sync or async context.

The in memory rate limiter is based on a token bucket. The bucket is filled with tokens at a given rate. Each request consumes a token. If there are not enough tokens in the bucket, the request is blocked until there are enough tokens.

These tokens have nothing to do with LLM tokens. They are just a way to keep track of how many requests can be made at a given time.

Current limitations:

  • The rate limiter is not designed to work across different processes. It is an in-memory rate limiter, but it is thread safe.
  • The rate limiter only supports time-based rate limiting. It does not take into account the size of the request or any other factors.

Example

use agent_chain_core::rate_limiters::{InMemoryRateLimiter, InMemoryRateLimiterConfig, BaseRateLimiter};

let rate_limiter = InMemoryRateLimiter::new(InMemoryRateLimiterConfig {
    requests_per_second: 0.1,  // Can only make a request once every 10 seconds
    check_every_n_seconds: 0.1,  // Wake up every 100 ms to check whether allowed to make a request
    max_bucket_size: 10.0,  // Controls the maximum burst size
});

// In sync context
rate_limiter.acquire(true);

// In async context
rate_limiter.aacquire(true).await;

Implementations

Source

impl InMemoryRateLimiter

pub fn new(config: InMemoryRateLimiterConfig) -> Self

Create a new InMemoryRateLimiter with the given configuration.

These tokens have nothing to do with LLM tokens. They are just a way to keep track of how many requests can be made at a given time.

This rate limiter is designed to work in a threaded environment.

It works by filling up a bucket with tokens at a given rate. Each request consumes a given number of tokens. If there are not enough tokens in the bucket, the request is blocked until there are enough tokens.