RunnableSequence

Struct RunnableSequence 

pub struct RunnableSequence<R1, R2>
where R1: Runnable, R2: Runnable<Input = R1::Output>,
{ /* private fields */ }
A sequence of Runnables that are executed one after another.

The output of one Runnable is the input to the next. This is the most common composition pattern in LangChain.

Implementations

Source

impl<R1, R2> RunnableSequence<R1, R2>
where R1: Runnable, R2: Runnable<Input = R1::Output>,

pub fn new(first: R1, last: R2) -> Self

Create a new RunnableSequence.

pub fn with_name(self, name: impl Into<String>) -> Self

Create a new RunnableSequence with a name.