RouterRunnable

Struct RouterRunnable 

pub struct RouterRunnable<I, O>
where I: Send + Sync + Clone + Debug + 'static, O: Send + Sync + Clone + Debug + 'static,
{ /* private fields */ }
A Runnable that routes to a set of Runnable based on Input['key'].

Returns the output of the selected Runnable.

Example

use agent_chain_core::runnables::{RouterRunnable, RunnableLambda, RouterInput};

let add = RunnableLambda::new(|x: i32| Ok(x + 1));
let square = RunnableLambda::new(|x: i32| Ok(x * x));

let router = RouterRunnable::new()
    .add("add", add)
    .add("square", square);

let result = router.invoke(RouterInput::new("square", 3), None)?;
assert_eq!(result, 9);

Implementations

Source

impl<I, O> RouterRunnable<I, O>
where I: Send + Sync + Clone + Debug + 'static, O: Send + Sync + Clone + Debug + 'static,

pub fn new() -> Self

Create a new empty RouterRunnable.

pub fn from_runnables(runnables: HashMap<String, DynRunnable<I, O>>) -> Self

Create a new RouterRunnable from a HashMap of runnables.

pub fn add<R>(self, key: impl Into<String>, runnable: R) -> Self
where R: Runnable<Input = I, Output = O> + Send + Sync + 'static,

Add a runnable to the router.

pub fn with_name(self, name: impl Into<String>) -> Self

Set the name of this router.

pub fn config_specs(&self) -> Result<Vec<ConfigurableFieldSpec>, String>

Get the configurable field specs from all contained runnables.