pub enum StreamEvent {
Standard(StandardStreamEvent),
Custom(CustomStreamEvent),
}Expand description
Union type for stream events.
A stream event can be either a standard event following LangChain conventions, or a custom event created by the user.
Variants
Standard(StandardStreamEvent)
A standard stream event.
Custom(CustomStreamEvent)
A custom stream event.
Implementations
Sourceimpl StreamEvent
impl StreamEvent
Get the tags.
Sourcepub fn parent_ids(&self) -> &[String]
pub fn parent_ids(&self) -> &[String]
Get the parent IDs.
Sourcepub fn is_standard(&self) -> bool
pub fn is_standard(&self) -> bool
Check if this is a standard event.