pub struct StandardStreamEvent {
pub base: BaseStreamEvent,
pub data: EventData,
pub name: String,
}Expand description
A standard stream event that follows LangChain convention for event data.
Fields
base: BaseStreamEventThe base event fields.
data: EventDataEvent data.
The contents of the event data depend on the event type.
name: StringThe name of the Runnable that generated the event.
Implementations
Sourceimpl StandardStreamEvent
impl StandardStreamEvent
Sourcepub fn new(
event: impl Into<String>,
run_id: impl Into<String>,
name: impl Into<String>,
) -> Self
pub fn new( event: impl Into<String>, run_id: impl Into<String>, name: impl Into<String>, ) -> Self
Create a new StandardStreamEvent.
Set the tags for this event.
Sourcepub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
Set the metadata for this event.
Sourcepub fn with_parent_ids(self, parent_ids: Vec<String>) -> Self
pub fn with_parent_ids(self, parent_ids: Vec<String>) -> Self
Set the parent IDs for this event.