pub struct InjectedToolArg;Expand description
Annotation for tool arguments that are injected at runtime.
Tool arguments annotated with this are not included in the tool schema sent to language models and are instead injected during execution.