BaseToolkit

Trait BaseToolkit 

pub trait BaseToolkit: Send + Sync {
    // Required method
    fn get_tools(&self) -> Vec<Arc<dyn BaseTool>>;
}
Base class for toolkits containing related tools.

A toolkit is a collection of related tools that can be used together to accomplish a specific task or work with a particular system.

Required Methods

fn get_tools(&self) -> Vec<Arc<dyn BaseTool>>

Get all tools in the toolkit.

Implementors