Utilities to render tools.
This module provides functions for rendering tool descriptions
in various text formats, mirroring langchain_core.tools.render.
Functions
- render_
for_ prompt - Render tools in a format suitable for system prompts.
- render_
json - Render tools as a JSON array of tool definitions.
- render_
json_ compact - Render tools as a compact JSON array.
- render_
numbered_ list - Render tools as a numbered list.
- render_
text_ description - Render the tool name and description in plain text.
- render_
text_ description_ and_ args - Render the tool name, description, and args in plain text.
- render_
tool - Render a single tool as a formatted string.
- render_
with_ schemas - Render tools with their full schemas.
Type Aliases
- Tools
Renderer - Type alias for a tools renderer function.