pub struct Tool { /* private fields */ }Expand description
Tool that takes in a function or coroutine directly.
This is the simplest form of tool that takes a single string input and returns a string output.
Implementations
Sourceimpl Tool
impl Tool
Sourcepub fn new(
name: impl Into<String>,
func: Option<ToolFunc>,
description: impl Into<String>,
) -> Self
pub fn new( name: impl Into<String>, func: Option<ToolFunc>, description: impl Into<String>, ) -> Self
Create a new Tool.
Sourcepub fn with_coroutine(self, coroutine: AsyncToolFunc) -> Self
pub fn with_coroutine(self, coroutine: AsyncToolFunc) -> Self
Set the coroutine (async function).
Sourcepub fn with_args_schema(self, schema: ArgsSchema) -> Self
pub fn with_args_schema(self, schema: ArgsSchema) -> Self
Set the args schema.
Sourcepub fn with_return_direct(self, return_direct: bool) -> Self
pub fn with_return_direct(self, return_direct: bool) -> Self
Set whether to return directly.
Sourcepub fn with_response_format(self, format: ResponseFormat) -> Self
pub fn with_response_format(self, format: ResponseFormat) -> Self
Set the response format.
Set tags.
Sourcepub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
Set metadata.
Sourcepub fn with_extras(self, extras: HashMap<String, Value>) -> Self
pub fn with_extras(self, extras: HashMap<String, Value>) -> Self
Set extras.
Sourcepub fn from_function<F>(
func: F,
name: impl Into<String>,
description: impl Into<String>,
) -> Self
pub fn from_function<F>( func: F, name: impl Into<String>, description: impl Into<String>, ) -> Self
Create a Tool from a function.