Module structured

Module structured 

Structured tool that can operate on any number of inputs.

This module provides the StructuredTool struct for creating tools that accept multiple typed arguments, mirroring langchain_core.tools.structured.

Structs

StructuredTool
Tool that can operate on any number of inputs.
StructuredToolBuilder
Builder for creating StructuredTool instances.

Functions

create_args_schema
Helper function to create an args schema from field definitions.

Type Aliases

AsyncStructuredToolFunc
Type alias for async structured tool function.
StructuredToolFunc
Type alias for sync structured tool function.