StructuredTool

Struct StructuredTool 

pub struct StructuredTool { /* private fields */ }
Tool that can operate on any number of inputs.

Unlike Tool, which accepts a single string input, StructuredTool accepts a dictionary of typed arguments.

Implementations

Source

impl StructuredTool

pub fn new( name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self

Create a new StructuredTool.

pub fn with_func(self, func: StructuredToolFunc) -> Self

Set the sync function.

pub fn with_coroutine(self, coroutine: AsyncStructuredToolFunc) -> Self

Set the async function.

pub fn with_return_direct(self, return_direct: bool) -> Self

Set whether to return directly.

pub fn with_response_format(self, format: ResponseFormat) -> Self

Set the response format.

pub fn with_tags(self, tags: Vec<String>) -> Self

Set tags.

pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self

Set metadata.

pub fn with_extras(self, extras: HashMap<String, Value>) -> Self

Set extras.

pub fn with_handle_tool_error(self, handler: HandleToolError) -> Self

Set handle_tool_error.

pub fn with_handle_validation_error( self, handler: HandleValidationError, ) -> Self

Set handle_validation_error.

pub fn from_function<F>( func: F, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
where F: Fn(HashMap<String, Value>) -> Result<Value> + Send + Sync + 'static,

Create a tool from a function.

This is the main way to create a StructuredTool.

pub fn from_function_with_async<F, AF, Fut>( func: F, coroutine: AF, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
where F: Fn(HashMap<String, Value>) -> Result<Value> + Send + Sync + 'static, AF: Fn(HashMap<String, Value>) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Value>> + Send + 'static,

Create a tool from a sync and async function pair.

pub fn from_async_function<AF, Fut>( coroutine: AF, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
where AF: Fn(HashMap<String, Value>) -> Fut + Send + Sync + 'static, Fut: Future<Output = Result<Value>> + Send + 'static,

Create a tool from an async function only.