Module env

Module env 

Utilities for environment variables.

Adapted from langchain_core/utils/env.py

Structs

SecretString
A wrapper around a string that prevents it from being printed.

Enums

EnvError
Error types for environment operations.

Functions

env_var_is_set
Check if an environment variable is set.
from_env
Create a factory function that gets a value from an environment variable.
get_from_dict_or_env
Get a value from a dictionary or an environment variable.
get_from_env
Get a value from an environment variable.
secret_from_env
Create a factory function that gets a secret value from an environment variable.