pub trait BaseCallbackHandler:
LLMManagerMixin
+ ChainManagerMixin
+ ToolManagerMixin
+ RetrieverManagerMixin
+ CallbackManagerMixin
+ RunManagerMixin
+ Send
+ Sync
+ Debug {
// Provided methods
fn raise_error(&self) -> bool { ... }
fn run_inline(&self) -> bool { ... }
fn ignore_llm(&self) -> bool { ... }
fn ignore_retry(&self) -> bool { ... }
fn ignore_chain(&self) -> bool { ... }
fn ignore_agent(&self) -> bool { ... }
fn ignore_retriever(&self) -> bool { ... }
fn ignore_chat_model(&self) -> bool { ... }
fn ignore_custom_event(&self) -> bool { ... }
fn name(&self) -> &str { ... }
}Expand description
Base callback handler for LangChain.
This trait combines all the mixin traits and provides the base interface for callback handlers. Handlers can override specific methods they care about.
Provided Methods
Sourcefn raise_error(&self) -> bool
fn raise_error(&self) -> bool
Whether to raise an error if an exception occurs.
Sourcefn run_inline(&self) -> bool
fn run_inline(&self) -> bool
Whether to run the callback inline.
Sourcefn ignore_llm(&self) -> bool
fn ignore_llm(&self) -> bool
Whether to ignore LLM callbacks.
Sourcefn ignore_retry(&self) -> bool
fn ignore_retry(&self) -> bool
Whether to ignore retry callbacks.
Sourcefn ignore_chain(&self) -> bool
fn ignore_chain(&self) -> bool
Whether to ignore chain callbacks.
Sourcefn ignore_agent(&self) -> bool
fn ignore_agent(&self) -> bool
Whether to ignore agent callbacks.
Sourcefn ignore_retriever(&self) -> bool
fn ignore_retriever(&self) -> bool
Whether to ignore retriever callbacks.
Sourcefn ignore_chat_model(&self) -> bool
fn ignore_chat_model(&self) -> bool
Whether to ignore chat model callbacks.
Sourcefn ignore_custom_event(&self) -> bool
fn ignore_custom_event(&self) -> bool
Whether to ignore custom events.