pub struct ChatSession {
pub messages: Option<Vec<BaseMessage>>,
pub functions: Option<Vec<Value>>,
}Expand description
Chat Session.
A Chat Session represents a single conversation, channel, or other group of messages.
Example
ⓘ
use agent_chain_core::chat_sessions::ChatSession;
use agent_chain_core::messages::{BaseMessage, HumanMessage, AIMessage};
let session = ChatSession {
messages: Some(vec![
BaseMessage::Human(HumanMessage::new("Hello!")),
BaseMessage::AI(AIMessage::new("Hi there!")),
]),
functions: None,
};Fields
messages: Option<Vec<BaseMessage>>A sequence of the LangChain chat messages loaded from the source.
functions: Option<Vec<Value>>A sequence of the function calling specs for the messages.
Implementations
Sourceimpl ChatSession
impl ChatSession
Sourcepub fn with_messages(messages: Vec<BaseMessage>) -> Self
pub fn with_messages(messages: Vec<BaseMessage>) -> Self
Create a chat session with the given messages.
Sourcepub fn with_messages_and_functions(
messages: Vec<BaseMessage>,
functions: Vec<Value>,
) -> Self
pub fn with_messages_and_functions( messages: Vec<BaseMessage>, functions: Vec<Value>, ) -> Self
Create a chat session with the given messages and functions.
Sourcepub fn messages(&self) -> &[BaseMessage]
pub fn messages(&self) -> &[BaseMessage]
Get the messages in this session, or an empty slice if none.
Sourcepub fn functions(&self) -> &[Value]
pub fn functions(&self) -> &[Value]
Get the functions in this session, or an empty slice if none.
Sourcepub fn has_messages(&self) -> bool
pub fn has_messages(&self) -> bool
Check if this session has any messages.
Sourcepub fn has_functions(&self) -> bool
pub fn has_functions(&self) -> bool
Check if this session has any functions.