pub struct Document {
pub page_content: String,
pub id: Option<String>,
pub metadata: HashMap<String, Value>,
pub type_: String,
}Expand description
Class for storing a piece of text and associated metadata.
Document is for retrieval workflows, not chat I/O. For sending text
to an LLM in a conversation, use message types from the messages module.
Example
use agent_chain_core::documents::Document;
use std::collections::HashMap;
let document = Document::new("Hello, world!")
.with_metadata(HashMap::from([
("source".to_string(), serde_json::json!("https://example.com"))
]));Fields
page_content: StringString text content of the document.
id: Option<String>An optional identifier for the document.
Ideally this should be unique across the document collection and formatted as a UUID, but this will not be enforced.
metadata: HashMap<String, Value>Arbitrary metadata associated with the content.
type_: StringType identifier, always “Document”.
Implementations
Sourceimpl Document
impl Document
Sourcepub fn new(page_content: impl Into<String>) -> Self
pub fn new(page_content: impl Into<String>) -> Self
Create a new Document with the given page content.
Sourcepub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
Set the metadata.
Sourcepub fn with_metadata_entry(self, key: impl Into<String>, value: Value) -> Self
pub fn with_metadata_entry(self, key: impl Into<String>, value: Value) -> Self
Add a single metadata entry.