pub struct GenericFakeChatModel { /* private fields */ }Expand description
Generic fake chat model that can be used to test the chat model interface.
- Chat model should be usable in both sync and async tests
- Invokes
on_llm_new_tokento allow for testing of callback related code for new tokens. - Includes logic to break messages into message chunks to facilitate testing of streaming.
Implementations
Sourceimpl GenericFakeChatModel
impl GenericFakeChatModel
Sourcepub fn new<I>(messages: I) -> Self
pub fn new<I>(messages: I) -> Self
Create a new GenericFakeChatModel with an iterator of messages.
Sourcepub fn from_strings(messages: Vec<String>) -> Self
pub fn from_strings(messages: Vec<String>) -> Self
Create from a vector of strings (converted to AIMessages).
Sourcepub fn with_config(self, config: ChatModelConfig) -> Self
pub fn with_config(self, config: ChatModelConfig) -> Self
Set the configuration.