macro_rules! beta {
($name:expr) => { ... };
($name:expr, $($key:ident = $value:expr),+ $(,)?) => { ... };
(@set $params:expr, message, $value:expr) => { ... };
(@set $params:expr, obj_type, $value:expr) => { ... };
(@set $params:expr, addendum, $value:expr) => { ... };
}Expand description
Macro to mark a function or method as beta.
This macro emits a beta warning when the decorated item is called.
Example
ⓘ
use agent_chain_core::beta;
#[beta]
fn experimental_feature() {
// Implementation
}
#[beta(name = "custom_name", addendum = "Use stable_feature instead.")]
fn another_beta_feature() {
// Implementation
}