pub struct ToolCallChunk {
pub name: Option<String>,
pub args: Option<String>,
pub id: Option<String>,
pub index: Option<i32>,
}Expand description
A tool call chunk (yielded when streaming).
When merging tool call chunks, all string attributes are concatenated.
Chunks are only merged if their values of index are equal and not None.
Fields
name: Option<String>The name of the tool to be called (may be partial during streaming)
args: Option<String>The arguments to the tool call (may be partial JSON string during streaming)
id: Option<String>An identifier associated with the tool call
index: Option<i32>The index of the tool call in a sequence
Implementations