pub struct InMemoryRateLimiterConfig {
pub requests_per_second: f64,
pub check_every_n_seconds: f64,
pub max_bucket_size: f64,
}Expand description
Configuration for InMemoryRateLimiter.
Fields
requests_per_second: f64The number of tokens to add per second to the bucket. The tokens represent “credit” that can be used to make requests.
check_every_n_seconds: f64Check whether the tokens are available every this many seconds. Can be a float to represent fractions of a second.
max_bucket_size: f64The maximum number of tokens that can be in the bucket. Must be at least 1. Used to prevent bursts of requests.