pub struct SimpleRetriever {
pub docs: Vec<Document>,
pub k: usize,
/* private fields */
}Expand description
A simple retriever that returns documents from a static list.
This is useful for testing or for simple use cases where documents are known ahead of time.
Fields
docs: Vec<Document>The list of documents to return.
k: usizeThe maximum number of documents to return.
Implementations
Sourceimpl SimpleRetriever
impl SimpleRetriever
Set the tags for this retriever.
Sourcepub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
Set the metadata for this retriever.