pub struct RunnableSequence<R1, R2>{ /* private fields */ }Expand description
A sequence of Runnables that are executed one after another.
The output of one Runnable is the input to the next. This is the most common composition pattern in LangChain.
Implementations