pub struct RouterRunnable<I, O>{ /* private fields */ }Expand description
A Runnable that routes to a set of Runnable based on Input['key'].
Returns the output of the selected Runnable.
Example
ⓘ
use agent_chain_core::runnables::{RouterRunnable, RunnableLambda, RouterInput};
let add = RunnableLambda::new(|x: i32| Ok(x + 1));
let square = RunnableLambda::new(|x: i32| Ok(x * x));
let router = RouterRunnable::new()
.add("add", add)
.add("square", square);
let result = router.invoke(RouterInput::new("square", 3), None)?;
assert_eq!(result, 9);Implementations
Sourceimpl<I, O> RouterRunnable<I, O>
impl<I, O> RouterRunnable<I, O>
Sourcepub fn from_runnables(runnables: HashMap<String, DynRunnable<I, O>>) -> Self
pub fn from_runnables(runnables: HashMap<String, DynRunnable<I, O>>) -> Self
Create a new RouterRunnable from a HashMap of runnables.
Sourcepub fn config_specs(&self) -> Result<Vec<ConfigurableFieldSpec>, String>
pub fn config_specs(&self) -> Result<Vec<ConfigurableFieldSpec>, String>
Get the configurable field specs from all contained runnables.