Module render

Module render 

Utilities to render tools.

This module provides functions for rendering tool descriptions in various text formats, mirroring langchain_core.tools.render.

Functions

render_for_prompt
Render tools in a format suitable for system prompts.
render_json
Render tools as a JSON array of tool definitions.
render_json_compact
Render tools as a compact JSON array.
render_numbered_list
Render tools as a numbered list.
render_text_description
Render the tool name and description in plain text.
render_text_description_and_args
Render the tool name, description, and args in plain text.
render_tool
Render a single tool as a formatted string.
render_with_schemas
Render tools with their full schemas.

Type Aliases

ToolsRenderer
Type alias for a tools renderer function.