Tool that takes in function or coroutine directly.
This module provides the Tool struct for creating simple single-input tools,
mirroring langchain_core.tools.simple.
Structs
- Tool
- Tool that takes in a function or coroutine directly.
- Tool
Builder - Builder for creating Tool instances.
Type Aliases
- Async
Tool Func - Type alias for async tool function.
- Tool
Func - Type alias for sync tool function.