Structured tool that can operate on any number of inputs.
This module provides the StructuredTool struct for creating tools
that accept multiple typed arguments, mirroring langchain_core.tools.structured.
Structs
- Structured
Tool - Tool that can operate on any number of inputs.
- Structured
Tool Builder - Builder for creating StructuredTool instances.
Functions
- create_
args_ schema - Helper function to create an args schema from field definitions.
Type Aliases
- Async
Structured Tool Func - Type alias for async structured tool function.
- Structured
Tool Func - Type alias for sync structured tool function.