pub struct StructuredTool { /* private fields */ }Expand description
Tool that can operate on any number of inputs.
Unlike Tool, which accepts a single string input, StructuredTool
accepts a dictionary of typed arguments.
Implementations
Sourceimpl StructuredTool
impl StructuredTool
Sourcepub fn new(
name: impl Into<String>,
description: impl Into<String>,
args_schema: ArgsSchema,
) -> Self
pub fn new( name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
Create a new StructuredTool.
Sourcepub fn with_func(self, func: StructuredToolFunc) -> Self
pub fn with_func(self, func: StructuredToolFunc) -> Self
Set the sync function.
Sourcepub fn with_coroutine(self, coroutine: AsyncStructuredToolFunc) -> Self
pub fn with_coroutine(self, coroutine: AsyncStructuredToolFunc) -> Self
Set the async function.
Sourcepub fn with_return_direct(self, return_direct: bool) -> Self
pub fn with_return_direct(self, return_direct: bool) -> Self
Set whether to return directly.
Sourcepub fn with_response_format(self, format: ResponseFormat) -> Self
pub fn with_response_format(self, format: ResponseFormat) -> Self
Set the response format.
Set tags.
Sourcepub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
pub fn with_metadata(self, metadata: HashMap<String, Value>) -> Self
Set metadata.
Sourcepub fn with_extras(self, extras: HashMap<String, Value>) -> Self
pub fn with_extras(self, extras: HashMap<String, Value>) -> Self
Set extras.
Sourcepub fn with_handle_tool_error(self, handler: HandleToolError) -> Self
pub fn with_handle_tool_error(self, handler: HandleToolError) -> Self
Set handle_tool_error.
Sourcepub fn with_handle_validation_error(
self,
handler: HandleValidationError,
) -> Self
pub fn with_handle_validation_error( self, handler: HandleValidationError, ) -> Self
Set handle_validation_error.
Sourcepub fn from_function<F>(
func: F,
name: impl Into<String>,
description: impl Into<String>,
args_schema: ArgsSchema,
) -> Self
pub fn from_function<F>( func: F, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
Create a tool from a function.
This is the main way to create a StructuredTool.
Sourcepub fn from_function_with_async<F, AF, Fut>(
func: F,
coroutine: AF,
name: impl Into<String>,
description: impl Into<String>,
args_schema: ArgsSchema,
) -> Self
pub fn from_function_with_async<F, AF, Fut>( func: F, coroutine: AF, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
Create a tool from a sync and async function pair.
Sourcepub fn from_async_function<AF, Fut>(
coroutine: AF,
name: impl Into<String>,
description: impl Into<String>,
args_schema: ArgsSchema,
) -> Self
pub fn from_async_function<AF, Fut>( coroutine: AF, name: impl Into<String>, description: impl Into<String>, args_schema: ArgsSchema, ) -> Self
Create a tool from an async function only.