Utilities for environment variables.
Adapted from langchain_core/utils/env.py
Structs
- Secret
String - A wrapper around a string that prevents it from being printed.
Enums
- EnvError
- Error types for environment operations.
Functions
- env_
var_ is_ set - Check if an environment variable is set.
- from_
env - Create a factory function that gets a value from an environment variable.
- get_
from_ dict_ or_ env - Get a value from a dictionary or an environment variable.
- get_
from_ env - Get a value from an environment variable.
- secret_
from_ env - Create a factory function that gets a secret value from an environment variable.